@@ -1,5 +1,6 @@
 import time
 import unittest
+import warnings
 
 from vika import Vika
 
@@ -7,7 +8,9 @@ from . import TEST_API_BASE, TEST_API_TOKEN, TEST_TABLE
 
 
 class TestDeleteRecords(unittest.TestCase):
+
     def setUp(self):
+        warnings.simplefilter('ignore', ResourceWarning)
         vika = Vika(TEST_API_TOKEN)
         vika.set_api_base(TEST_API_BASE)
         self.dst = vika.datasheet(TEST_TABLE)
