@@ -1,4 +1,5 @@
 import unittest
+import warnings
 
 from vika import Vika
 
@@ -6,7 +7,9 @@ from .env import TEST_API_BASE, TEST_API_TOKEN, TEST_SPACE_ID, TEST_FOLDER_ID
 
 
 class TestGetNodes(unittest.TestCase):
+
     def setUp(self):
+        warnings.simplefilter('ignore', ResourceWarning)
         vika = Vika(TEST_API_TOKEN)
         vika.set_api_base(TEST_API_BASE)
         self.vika = vika
