@@ -1,11 +1,14 @@
 import unittest
+import warnings
 
 from vika import Vika
 from . import TEST_API_BASE, TEST_API_TOKEN
 
 
 class TestGetSpaces(unittest.TestCase):
+
     def setUp(self):
+        warnings.simplefilter('ignore', ResourceWarning)
         vika = Vika(TEST_API_TOKEN)
         vika.set_api_base(TEST_API_BASE)
         self.vika = vika
