@@ -2,7 +2,9 @@ API_BASE = "https://vika.cn"
 
 API_ENDPOINT_DATASHEET = "/fusion/v1/datasheets"
 
-MAX_COUNT_CREATE_RECORDS_ONCE = 10
+MAX_WRITE_RECORDS_PRE_REQ = 10
+
+MAX_GET_RECORDS_PRE_REQ = 1000
 
 API_GET_DATASHEET_QS_SET = {
     "viewId",
