@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import Optional
 
 from pydantic import BaseModel
 
@@ -8,9 +9,11 @@ class ViewTypeEnum(str, Enum):
     Gallery = 'Gallery'
     Kanban = 'Kanban'
     Gantt = 'Gantt'
+    Calendar = 'Calendar'
+    Architecture = 'Architecture'
 
 
 class MetaView(BaseModel):
     id: str
     name: str
-    type: ViewTypeEnum
+    type: Optional[ViewTypeEnum]
